@@ -11,7 +11,10 @@ use hyper::body::HttpBody;
 use serde::{de::DeserializeOwned, Serialize};
 use tokio::io::AsyncRead;
 
-use crate::error::{ParseJsonError, ReadBodyError};
+use crate::{
+    error::{ParseJsonError, ReadBodyError},
+    Result,
+};
 
 /// A body object for requests and responses.
 #[derive(Default)]
@@ -141,8 +144,13 @@ impl Body {
     }
 
     /// Consumes this body object and parse it as `T`.
-    pub async fn into_json<T: DeserializeOwned>(self) -> Result<T, ParseJsonError> {
-        Ok(serde_json::from_slice(&self.into_vec().await?)?)
+    ///
+    /// # Errors
+    ///
+    /// - [`ReadBodyError`]
+    /// - [`ParseJsonError`]
+    pub async fn into_json<T: DeserializeOwned>(self) -> Result<T> {
+        Ok(serde_json::from_slice(&self.into_vec().await?).map_err(ParseJsonError)?)
     }
 
     /// Consumes this body object to return a reader.
